㊙️ python-barcode's documentation
===================================

.. image:: _static/images/pybarcode.png

Contents
--------

.. toctree::
   :maxdepth: 2

   barcode
   commandline
   codes
   writers/index
   license
